@@ -1,4 +1,5 @@
 use super::super::common;
+use hydrus_api::api_core::common::FileIdentifier;
 use hydrus_api::wrapper::page::HydrusPage;
 
 async fn get_page() -> HydrusPage {
@@ -30,3 +31,14 @@ async fn it_has_a_id() {
     let page = get_page().await;
     page.id();
 }
+
+#[tokio::test]
+async fn it_can_have_files_assigned() {
+    let page = get_page().await;
+    let result = page
+        .add_files(vec![FileIdentifier::hash(
+            "0000000000000000000000000000000000000000000000000000000000000000",
+        )])
+        .await;
+    assert!(result.is_err()) // root pages are not media pages
+}
